#
# This file is part of Dist-Metadata
#
# This software is copyright (c) 2011 by Randy Stauner.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#
package Dist::Metadata::Test::MetaFile;
# ABSTRACT: Fake dist for testing metadata determination

# does not match META file but we trust the META file
our $VERSION = '1.5';
